@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,13 +22,18 @@
 #include "ImageViewBase.h"
 #include "DragHandler.h"
 #include "ZoomHandler.h"
+#include "ImagePixmapUnion.h"
+#include "Margins.h"
 #include <QImage>
 
 class BasicImageView : public ImageViewBase
 {
 	Q_OBJECT
 public:
-	BasicImageView(QImage const& image, QImage const& downscaled_image = QImage());
+	BasicImageView(
+		QImage const& image,
+		ImagePixmapUnion const& downscaled_image = ImagePixmapUnion(),
+		Margins const& margins = Margins());
 	
 	virtual ~BasicImageView();
 private:
