@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ public:
 	virtual ~CompositeCacheDrivenTask() {}
 	
 	virtual void process(
-		PageInfo const& page_info, int page_num,
+		PageInfo const& page_info,
 		AbstractFilterDataCollector* collector) = 0;
 };
 
