@@ -101,6 +101,11 @@ Settings::get(Despeckle::Level const level, Dpi const& dpi)
 	int const min_dpi = std::min(dpi.horizontal(), dpi.vertical());
 	double const dpi_factor = min_dpi / 300.0;
 
+	// To silence compiler's warnings.
+	settings.minRelativeParentWeight = 0;
+	settings.pixelsToSqDist = 0;
+	settings.bigObjectThreshold = 0;
+
 	switch (level) {
 		case Despeckle::CAUTIOUS:
 			settings.minRelativeParentWeight = 0.125 * dpi_factor;
@@ -350,7 +355,8 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 	int const width = cmap.size().width() + 2;
 	int const height = cmap.size().height() + 2;
 	
-	dist.resize(width * height); // We don't really need to initialize it.
+	assert(dist.empty());
+	dist.resize(width * height, Distance::zero());
 	
 	std::vector<uint32_t> sqdists(width * 2, 0);
 	uint32_t* prev_sqdist_line = &sqdists[0];
@@ -368,7 +374,7 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 	}
 	
 	// Top to bottom scan.
-	for (int y = 1; y < height - 1; ++y) {
+	for (int y = 1; y < height; ++y) {
 		dist_line += width;
 		cmap_line += width;
 		dist_line[0].reset(0);
@@ -379,6 +385,7 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 		for (int x = 1; x < width - 1; ++x) {
 			if (cmap_line[x]) {
 				this_sqdist_line[x] = 0;
+				assert(dist_line[x] == Distance::zero());
 				continue;
 			}
 			
@@ -411,7 +418,7 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 			Distance right_dist = dist_line[x + 1];
 			uint32_t sqdist_right = this_sqdist_line[x + 1];
 			sqdist_right += 1 + (int(right_dist.vec.x) << 1);
-			
+
 			if (sqdist_right < this_sqdist_line[x]) {
 				this_sqdist_line[x] = sqdist_right;
 				++right_dist.vec.x;
@@ -423,14 +430,6 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 		std::swap(this_sqdist_line, prev_sqdist_line);
 	}
 	
-	dist_line[0].reset(0);
-	prev_sqdist_line[0] = dist_line[0].sqdist();
-	for (int x = 1; x < width; ++x) {
-		dist_line[x].vec.x = dist_line[x - 1].vec.x - 1;
-		prev_sqdist_line[x] = prev_sqdist_line[x - 1]
-				- (int(dist_line[x - 1].vec.x) << 1) + 1;
-	}
-	
 	// Bottom to top scan.
 	for (int y = height - 2; y >= 1; --y) {
 		dist_line -= width;
@@ -450,19 +449,21 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 			Distance bottom_dist = dist_line[x + width];
 			uint32_t sqdist_bottom = prev_sqdist_line[x];
 			sqdist_bottom += VERTICAL_SCALE_SQ + 2 * VERTICAL_SCALE_SQ * int(bottom_dist.vec.y);
-			
+
 			this_sqdist_line[x] = dist_line[x].sqdist();
 			
 			if (sqdist_right < this_sqdist_line[x]) {
 				this_sqdist_line[x] = sqdist_right;
 				++right_dist.vec.x;
 				dist_line[x] = right_dist;
+				assert(cmap_line[x] == 0 || cmap_line[x + 1] != 0);
 				cmap_line[x] = cmap_line[x + 1];
 			}
 			if (sqdist_bottom < this_sqdist_line[x]) {
 				this_sqdist_line[x] = sqdist_bottom;
 				++bottom_dist.vec.y;
 				dist_line[x] = bottom_dist;
+				assert(cmap_line[x] == 0 || cmap_line[x + width] != 0);
 				cmap_line[x] = cmap_line[x + width];
 			}
 		}
@@ -478,6 +479,7 @@ void voronoi(ConnectivityMap& cmap, std::vector<Distance>& dist)
 				this_sqdist_line[x] = sqdist_left;
 				--left_dist.vec.x;
 				dist_line[x] = left_dist;
+				assert(cmap_line[x] == 0 || cmap_line[x - 1] != 0);
 				cmap_line[x] = cmap_line[x - 1];
 			}
 		}
@@ -497,6 +499,14 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 	
 	Distance* dist_line = &dist[0];
 	uint32_t* cmap_line = cmap.paddedData();
+
+	dist_line[0].reset(0);
+	prev_sqdist_line[0] = dist_line[0].sqdist();
+	for (int x = 1; x < width; ++x) {
+		dist_line[x].vec.x = dist_line[x - 1].vec.x - 1;
+		prev_sqdist_line[x] = prev_sqdist_line[x - 1]
+				- (int(dist_line[x - 1].vec.x) << 1) + 1;
+	}
 	
 	// Top to bottom scan.
 	for (int y = 1; y < height - 1; ++y) {
@@ -523,6 +533,7 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 					this_sqdist_line[x] = sqdist_left;
 					--left_dist.vec.x;
 					dist_line[x] = left_dist;
+					assert(cmap_line[x] == 0 || cmap_line[x - 1] != 0);
 					cmap_line[x] = cmap_line[x - 1];
 				}
 			}
@@ -536,6 +547,7 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 					this_sqdist_line[x] = sqdist_top;
 					--top_dist.vec.y;
 					dist_line[x] = top_dist;
+					assert(cmap_line[x] == 0 || cmap_line[x - width] != 0);
 					cmap_line[x] = cmap_line[x - width];
 				}
 			}
@@ -556,6 +568,7 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 					this_sqdist_line[x] = sqdist_right;
 					++right_dist.vec.x;
 					dist_line[x] = right_dist;
+					assert(cmap_line[x] == 0 || cmap_line[x + 1] != 0);
 					cmap_line[x] = cmap_line[x + 1];
 				}
 			}
@@ -589,6 +602,7 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 					this_sqdist_line[x] = sqdist_right;
 					++right_dist.vec.x;
 					dist_line[x] = right_dist;
+					assert(cmap_line[x] == 0 || cmap_line[x + 1] != 0);
 					cmap_line[x] = cmap_line[x + 1];
 				}
 			}
@@ -602,6 +616,7 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 					this_sqdist_line[x] = sqdist_bottom;
 					++bottom_dist.vec.y;
 					dist_line[x] = bottom_dist;
+					assert(cmap_line[x] == 0 || cmap_line[x + width] != 0);
 					cmap_line[x] = cmap_line[x + width];
 				}
 			}
@@ -622,6 +637,7 @@ void voronoiSpecial(ConnectivityMap& cmap, std::vector<Distance>& dist, Distance
 					this_sqdist_line[x] = sqdist_left;
 					--left_dist.vec.x;
 					dist_line[x] = left_dist;
+					assert(cmap_line[x] == 0 || cmap_line[x - 1] != 0);
 					cmap_line[x] = cmap_line[x - 1];
 				}
 			}
