@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2009  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "FixDpiDialog.h"
 #include "FixDpiDialog.h.moc"
 #include <QAbstractItemModel>
 #include <QSortFilterProxyModel>
@@ -471,6 +472,9 @@ FixDpiDialog::decorateDpiInputField(QLineEdit* field, ImageMetadata::DpiStatus d
 		case ImageMetadata::DPI_UNDEFINED:
 			field->setToolTip(QString());
 			break;
+		case ImageMetadata::DPI_TOO_LARGE:
+			field->setToolTip(tr("DPI is too large and most likely wrong."));
+			break;
 		case ImageMetadata::DPI_TOO_SMALL:
 			field->setToolTip(tr("DPI is too small. Even if it's correct, you are not going to get acceptable results with it."));
 			break;
