@@ -22,6 +22,7 @@
 #include "ui_MainWindow.h"
 #include "FilterUiInterface.h"
 #include "NonCopyable.h"
+#include "AbstractCommand.h"
 #include "IntrusivePtr.h"
 #include "BackgroundTask.h"
 #include "FilterResult.h"
@@ -43,11 +44,13 @@
 #include <set>
 
 class AbstractFilter;
+class AbstractRelinker;
 class ThumbnailPixmapCache;
 class ProjectPages;
 class PageSequence;
 class StageSequence;
 class PageOrderProvider;
+class PageSelectionAccessor;
 class FilterOptionsWidget;
 class ProcessingIndicationWidget;
 class ImageInfo;
@@ -63,6 +66,8 @@ class ProjectOpeningContext;
 class CompositeCacheDrivenTask;
 class TabbedDebugImages;
 class ProcessingTaskQueue;
+class FixDpiDialog;
+class OutOfMemoryDialog;
 class QLineF;
 class QRectF;
 class QLayout;
@@ -131,6 +136,8 @@ private slots:
 	void invalidateThumbnail(PageInfo const& page_info);
 	
 	void invalidateAllThumbnails();
+
+	void showRelinkingDialog();
 	
 	void filterResult(
 		BackgroundTaskPtr const& task,
@@ -138,6 +145,10 @@ private slots:
 	
 	void debugToggled(bool enabled);
 	
+	void fixDpiDialogRequested();
+
+	void fixedDpiSubmitted();
+
 	void saveProjectTriggered();
 	
 	void saveProjectAsTriggered();
@@ -155,7 +166,10 @@ private slots:
 	void openSettingsDialog();
 
 	void showAboutDialog();
+
+	void handleOutOfMemorySituation();
 private:
+	class PageSelectionProviderImpl;
 	enum SavePromptResult { SAVE, DONT_SAVE, CANCEL };
 	
 	typedef IntrusivePtr<AbstractFilter> FilterPtr;
@@ -166,6 +180,8 @@ private:
 	virtual void setImageWidget(
 		QWidget* widget, Ownership ownership,
 		DebugImages* debug_images = 0);
+
+	virtual IntrusivePtr<AbstractCommand0<void> > relinkingDialogRequester();
 	
 	void switchToNewProject(
 		IntrusivePtr<ProjectPages> const& pages,
@@ -249,6 +265,10 @@ private:
 	void createBatchProcessingWidget();
 
 	void updateDisambiguationRecords(PageSequence const& pages);
+
+	void performRelinking(IntrusivePtr<AbstractRelinker> const& relinker);
+
+	PageSelectionAccessor newPageSelectionAccessor();
 	
 	QSizeF m_maxLogicalThumbSize;
 	IntrusivePtr<ProjectPages> m_ptrPages;
@@ -263,6 +283,7 @@ private:
 	QStackedLayout* m_pImageFrameLayout;
 	QStackedLayout* m_pOptionsFrameLayout;
 	QPointer<FilterOptionsWidget> m_ptrOptionsWidget;
+	QPointer<FixDpiDialog> m_ptrFixDpiDialog;
 	std::auto_ptr<TabbedDebugImages> m_ptrTabbedDebugImages;
 	std::auto_ptr<ContentBoxPropagator> m_ptrContentBoxPropagator;
 	std::auto_ptr<PageOrientationPropagator> m_ptrPageOrientationPropagator;
@@ -272,6 +293,7 @@ private:
 	SelectedPage m_selectedPage;
 	QObjectCleanupHandler m_optionsWidgetCleanup;
 	QObjectCleanupHandler m_imageWidgetCleanup;
+	std::auto_ptr<OutOfMemoryDialog> m_ptrOutOfMemoryDialog;
 	int m_curFilter;
 	int m_ignoreSelectionChanges;
 	int m_ignorePageOrderingChanges;
