@@ -18,7 +18,7 @@
 
 #include "OpenGLSupport.h"
 #include "config.h"
-#include "settings/ini_keys.h"
+#include <QSettings>
 #ifdef ENABLE_OPENGL
 #include <QGLFormat>
 #include <QGLWidget>
