@@ -29,13 +29,11 @@ class PageOrderOption
 public:
 	typedef IntrusivePtr<PageOrderProvider const> ProviderPtr;
 
-    PageOrderOption(QString const& name, ProviderPtr const& provider, QString const& toolTip = QString())
-        : m_name(name), m_ptrProvider(provider), m_toolTip(toolTip) {}
+	PageOrderOption(QString const& name, ProviderPtr const& provider)
+		: m_name(name), m_ptrProvider(provider) {}
 
 	QString const& name() const { return m_name; }
 
-    QString const& toolTip() const { return m_toolTip; }
-
 	/**
 	 * Returns the ordering information provider.
 	 * A null provider is OK and is to be interpreted as default order.
@@ -44,7 +42,6 @@ public:
 private:
 	QString m_name;
 	ProviderPtr m_ptrProvider;
-    QString m_toolTip;
 };
 
 #endif
