@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2009  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,9 +16,10 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "ProjectOpeningContext.h"
 #include "ProjectOpeningContext.h.moc"
 #include "FixDpiDialog.h"
-#include "PageSequence.h"
+#include "ProjectPages.h"
 #include <QString>
 #include <QMessageBox>
 #include <Qt>
