@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "PageId.h"
 #include "ImageInfo.h"
 #include "ImageMetadata.h"
+#include "SelectedPage.h"
 #include "IntrusivePtr.h"
 #include <QString>
 #include <QDomDocument>
@@ -32,7 +33,8 @@
 
 class QDomElement;
 class ProjectData;
-class PageSequence;
+class ProjectPages;
+class FileNameDisambiguator;
 class AbstractFilter;
 
 class ProjectReader
@@ -50,27 +52,31 @@ public:
 	
 	QString const& outputDirectory() const { return m_outDir; }
 	
-	IntrusivePtr<PageSequence> const& pages() const { return m_ptrPages; }
+	IntrusivePtr<ProjectPages> const& pages() const { return m_ptrPages; }
+
+	SelectedPage const& selectedPage() const { return m_selectedPage; }
+
+	IntrusivePtr<FileNameDisambiguator> const& namingDisambiguator() const {
+		return m_ptrDisambiguator;
+	}
 	
 	ImageId imageId(int numeric_id) const;
 	
 	PageId pageId(int numeric_id) const;
 private:
-	struct FileInfo
+	struct FileRecord
 	{
-		QString path;
-		bool multiPageFile;
-		
-		FileInfo() : multiPageFile(false) {}
-		
-		FileInfo(QString path, bool multi_page)
-		: path(path), multiPageFile(multi_page) {}
-		
-		bool isNull() const { return path.isEmpty(); }
+		QString filePath;
+		bool compatMultiPage; // Backwards compatibility.
+
+		FileRecord() : compatMultiPage(false) {}
+
+		FileRecord(QString const& file_path, bool compat_multi_page)
+			: filePath(file_path), compatMultiPage(compat_multi_page) {}
 	};
-	
+
 	typedef std::map<int, QString> DirMap;
-	typedef std::map<int, FileInfo> FileMap;
+	typedef std::map<int, FileRecord> FileMap;
 	typedef std::map<int, ImageInfo> ImageMap;
 	typedef std::map<int, PageId> PageMap;
 	
@@ -87,7 +93,9 @@ private:
 	
 	QString getDirPath(int id) const;
 	
-	FileInfo getFileInfo(int id) const;
+	FileRecord getFileRecord(int id) const;
+
+	QString expandFilePath(QString const& path_shorthand) const;
 	
 	ImageInfo getImageInfo(int id) const;
 	
@@ -97,7 +105,9 @@ private:
 	FileMap m_fileMap;
 	ImageMap m_imageMap;
 	PageMap m_pageMap;
-	IntrusivePtr<PageSequence> m_ptrPages;
+	SelectedPage m_selectedPage;
+	IntrusivePtr<ProjectPages> m_ptrPages;
+	IntrusivePtr<FileNameDisambiguator> m_ptrDisambiguator;
 };
 
 #endif
