@@ -20,6 +20,8 @@
 #include "ImageId.h"
 #include "ImageLoader.h"
 #include "AtomicFileOverwriter.h"
+#include "RelinkablePath.h"
+#include "OutOfMemoryHandler.h"
 #include "imageproc/Scale.h"
 #include "imageproc/GrayImage.h"
 #include <QCoreApplication>
@@ -42,7 +44,9 @@
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index/member.hpp>
 #include <boost/foreach.hpp>
+#include <algorithm>
 #include <vector>
+#include <new>
 
 using namespace ::boost;
 using namespace ::boost::multi_index;
@@ -110,6 +114,8 @@ public:
 		int max_cached_pixmaps, int expiration_threshold);
 	
 	~Impl();
+
+	void setThumbDir(QString const& thumb_dir);
 	
 	Status request(
 		ImageId const& image_id, QPixmap& pixmap, bool load_now = false,
@@ -260,7 +266,7 @@ ThumbnailPixmapCache::ThumbnailPixmapCache(
 	int const max_cached_pixmaps, int const expiration_threshold)
 :	m_ptrImpl(
 		new Impl(
-			thumb_dir, max_thumb_size,
+			RelinkablePath::normalize(thumb_dir), max_thumb_size,
 			max_cached_pixmaps, expiration_threshold
 		)
 	)
@@ -271,6 +277,12 @@ ThumbnailPixmapCache::~ThumbnailPixmapCache()
 {
 }
 
+void
+ThumbnailPixmapCache::setThumbDir(QString const& thumb_dir)
+{
+	m_ptrImpl->setThumbDir(RelinkablePath::normalize(thumb_dir));
+}
+
 ThumbnailPixmapCache::Status
 ThumbnailPixmapCache::loadFromCache(ImageId const& image_id, QPixmap& pixmap)
 {
@@ -327,7 +339,12 @@ ThumbnailPixmapCache::Impl::Impl(
 	m_threadStarted(false),
 	m_shuttingDown(false)
 {
-	QDir().mkpath(m_thumbDir);
+	// Note that QDir::mkdir() will fail if the parent directory,
+	// that is $OUT/cache doesn't exist. We want that behaviour,
+	// as otherwise when loading a project from a different machine,
+	// a whole bunch of bogus directories would be created.
+	QDir().mkdir(m_thumbDir);
+
 	m_backgroundLoader.moveToThread(this);
 }
 
@@ -347,6 +364,26 @@ ThumbnailPixmapCache::Impl::~Impl()
 	wait();
 }
 
+void
+ThumbnailPixmapCache::Impl::setThumbDir(QString const& thumb_dir)
+{
+	QMutexLocker locker(&m_mutex);
+
+	if (thumb_dir == m_thumbDir) {
+		return;
+	}
+
+	m_thumbDir = thumb_dir;
+
+	BOOST_FOREACH(Item const& item, m_loadQueue) {
+		// This trick will make all queued tasks to expire.
+		m_totalLoadAttempts = std::max(
+			m_totalLoadAttempts,
+			item.precedingLoadAttempts + m_expirationThreshold + 1
+		);
+	}
+}
+
 ThumbnailPixmapCache::Status
 ThumbnailPixmapCache::Impl::request(
 	ImageId const& image_id, QPixmap& pixmap, bool const load_now,
@@ -561,66 +598,70 @@ ThumbnailPixmapCache::Impl::backgroundProcessing()
 	assert(QCoreApplication::instance()->thread() != QThread::currentThread());
 	
 	for (;;) {
-		// We are going to initialize these while holding the mutex.
-		LoadQueue::iterator lq_it;
-		ImageId image_id;
-		QString thumb_dir;
-		QSize max_thumb_size;
-		
-		{
-			QMutexLocker const locker(&m_mutex);
-			
-			if (m_shuttingDown || m_items.empty()) {
-				break;
-			}
-			
-			lq_it = m_loadQueue.begin();
-			image_id = lq_it->imageId;
-			
-			if (lq_it->status != Item::QUEUED) {
-				// All QUEUED items precede any other items
-				// in the load queue, so it means there are no
-				// QUEUED items at all.
-				assert(m_numQueuedItems == 0);
-				break;
-			}
-			
-			// By marking the item as IN_PROGRESS, we prevent it
-			// from being processed again before the GUI thread
-			// receives our LoadResultEvent.
-			queuedToInProgress(lq_it);
-			
-			if (m_totalLoadAttempts - lq_it->precedingLoadAttempts
-					> m_expirationThreshold) {
-				
-				// Expire this request.  The reasoning behind
-				// request expiration is described in
-				// ThumbnailLoadResult::REQUEST_EXPIRED
-				// documentation.
-				
-				postLoadResult(
-					lq_it, QImage(),
-					ThumbnailLoadResult::REQUEST_EXPIRED
-				);
-				continue;
-			}
-			
-			// Expired requests don't count as load attempts.
-			++m_totalLoadAttempts;
-			
-			// Copy those while holding the mutex.
-			thumb_dir = m_thumbDir;
-			max_thumb_size = m_maxThumbSize;
-		} // mutex scope
-		
-		QImage const image(
-			loadSaveThumbnail(image_id, thumb_dir, max_thumb_size)
-		);
-		
-		ThumbnailLoadResult::Status const status = image.isNull()
-			? ThumbnailLoadResult::LOAD_FAILED
-			: ThumbnailLoadResult::LOADED;
-		postLoadResult(lq_it, image, status);
+		try {
+			// We are going to initialize these while holding the mutex.
+			LoadQueue::iterator lq_it;
+			ImageId image_id;
+			QString thumb_dir;
+			QSize max_thumb_size;
+
+			{
+				QMutexLocker const locker(&m_mutex);
+
+				if (m_shuttingDown || m_items.empty()) {
+					break;
+				}
+
+				lq_it = m_loadQueue.begin();
+				image_id = lq_it->imageId;
+
+				if (lq_it->status != Item::QUEUED) {
+					// All QUEUED items precede any other items
+					// in the load queue, so it means there are no
+					// QUEUED items at all.
+					assert(m_numQueuedItems == 0);
+					break;
+				}
+
+				// By marking the item as IN_PROGRESS, we prevent it
+				// from being processed again before the GUI thread
+				// receives our LoadResultEvent.
+				queuedToInProgress(lq_it);
+
+				if (m_totalLoadAttempts - lq_it->precedingLoadAttempts
+						> m_expirationThreshold) {
+
+					// Expire this request.  The reasoning behind
+					// request expiration is described in
+					// ThumbnailLoadResult::REQUEST_EXPIRED
+					// documentation.
+
+					postLoadResult(
+						lq_it, QImage(),
+						ThumbnailLoadResult::REQUEST_EXPIRED
+					);
+					continue;
+				}
+
+				// Expired requests don't count as load attempts.
+				++m_totalLoadAttempts;
+
+				// Copy those while holding the mutex.
+				thumb_dir = m_thumbDir;
+				max_thumb_size = m_maxThumbSize;
+			} // mutex scope
+
+			QImage const image(
+				loadSaveThumbnail(image_id, thumb_dir, max_thumb_size)
+			);
+
+			ThumbnailLoadResult::Status const status = image.isNull()
+				? ThumbnailLoadResult::LOAD_FAILED
+				: ThumbnailLoadResult::LOADED;
+			postLoadResult(lq_it, image, status);
+		} catch (std::bad_alloc const&) {
+			OutOfMemoryHandler::instance().handleOutOfMemorySituation();
+		}
 	}
 }
 
