@@ -39,6 +39,7 @@
 #include <QPen>
 #include <QColor>
 #include <QDebug>
+#include <boost/foreach.hpp>
 #include <algorithm>
 #include <exception>
 #include <iterator>
@@ -155,8 +156,8 @@ DistortionModelBuilder::transform(QTransform const& xform)
 	m_bound1 = xform.map(m_bound1);
 	m_bound2 = xform.map(m_bound2);
 
-	for (std::vector<QPointF>& polyline: m_ltrPolylines) {
-		for (QPointF& pt: polyline) {
+	BOOST_FOREACH(std::vector<QPointF>& polyline, m_ltrPolylines) {
+		BOOST_FOREACH(QPointF& pt, polyline) {
 			pt = xform.map(pt);
 		}
 	}
@@ -174,7 +175,7 @@ DistortionModelBuilder::tryBuildModel(DebugImages* dbg, QImage const* dbg_backgr
 	std::vector<TracedCurve> ordered_curves;
 	ordered_curves.reserve(num_curves);
 	
-	for (std::vector<QPointF> const& polyline: m_ltrPolylines) {
+	BOOST_FOREACH(std::vector<QPointF> const& polyline, m_ltrPolylines) {
 		try {
 			ordered_curves.push_back(polylineToCurve(polyline));
 		} catch (BadCurve const&) {
@@ -487,7 +488,7 @@ try {
 	);
 
 	double error = 0;
-	for (TracedCurve const& curve: m_rAllCurves) {
+	BOOST_FOREACH(TracedCurve const& curve, m_rAllCurves) {
 		size_t const polyline_size = curve.trimmedPolyline.size();
 		double const r_reference_height = 1.0 / 1.0; //calcReferenceHeight(dewarper, curve.centroid);
 
@@ -498,7 +499,7 @@ try {
 		std::vector<double> B;
 		B.reserve(polyline_size);
 
-		for (QPointF const& warped_pt: curve.trimmedPolyline) {
+		BOOST_FOREACH(QPointF const& warped_pt, curve.trimmedPolyline) {
 			// TODO: add another signature with hint for efficiency.
 			QPointF const dewarped_pt(dewarper.mapToDewarpedSpace(warped_pt));
 
@@ -587,7 +588,7 @@ DistortionModelBuilder::visualizeTrimmedPolylines(
 	painter.drawLine(bound1);
 	painter.drawLine(bound2);
 
-	for (TracedCurve const& curve: curves) {
+	BOOST_FOREACH(TracedCurve const& curve, curves) {
 		if (!curve.trimmedPolyline.empty()) {
 			painter.drawPolyline(&curve.trimmedPolyline[0], curve.trimmedPolyline.size());
 		}
@@ -597,9 +598,9 @@ DistortionModelBuilder::visualizeTrimmedPolylines(
 	QBrush knot_brush(Qt::magenta);
 	painter.setBrush(knot_brush);
 	painter.setPen(Qt::NoPen);
-	for (TracedCurve const& curve: curves) {
+	BOOST_FOREACH(TracedCurve const& curve, curves) {
 		QRectF rect(0, 0, stroke_width, stroke_width);
-		for (QPointF const& knot: curve.trimmedPolyline) {
+		BOOST_FOREACH(QPointF const& knot, curve.trimmedPolyline) {
 			rect.moveCenter(knot);
 			painter.drawEllipse(rect);
 		}
@@ -647,7 +648,7 @@ DistortionModelBuilder::visualizeModel(
 
 	QBrush junction_point_brush(QColor(0xff, 0x00, 0xff, 255));
 
-	for (TracedCurve const& curve: curves) {
+	BOOST_FOREACH(TracedCurve const& curve, curves) {
 		if (curve.extendedPolyline.empty()) {
 			continue;
 		}
@@ -686,10 +687,10 @@ DistortionModelBuilder::visualizeModel(
 
 		if (!reverse_segments.empty()) {
 			painter.setPen(reverse_segments_pen);
-			for (std::vector<int> const& sequence: reverse_segments) {
+			BOOST_FOREACH(std::vector<int> const& sequence, reverse_segments) {
 				assert(!sequence.empty());
 				polyline.clear();
-				for (int idx: sequence) {
+				BOOST_FOREACH(int idx, sequence) {
 					polyline << curve.extendedPolyline[idx];
 				}
 				painter.drawPolyline(polyline); 
