@@ -24,11 +24,10 @@
 #include "imageproc/GrayImage.h"
 #include "imageproc/GaussBlur.h"
 #include "imageproc/Sobel.h"
-#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
-#endif
 #include <QImage>
 #include <QPainter>
 #include <QPen>
@@ -131,7 +130,7 @@ TextLineRefiner::refine(
 	snakes.reserve(polylines.size());
 	
 	// Convert from polylines to snakes.
-	for (std::vector<QPointF> const& polyline: polylines) {
+	BOOST_FOREACH(std::vector<QPointF> const& polyline, polylines) {
 		snakes.push_back(makeSnake(polyline, iterations));
 	}
 
@@ -146,7 +145,7 @@ TextLineRefiner::refine(
 	float v_sigma = (4.0f / 200.f) * m_dpi.vertical();
 	calcBlurredGradient(gradient, h_sigma, v_sigma);
 	
-	for (Snake& snake: snakes) {
+	BOOST_FOREACH(Snake& snake, snakes) {
 		evolveSnake(snake, gradient, ON_CONVERGENCE_STOP);
 	}
 	if (dbg) { 
@@ -158,7 +157,7 @@ TextLineRefiner::refine(
 	v_sigma *= 0.5f;
 	calcBlurredGradient(gradient, h_sigma, v_sigma);
 	
-	for (Snake& snake: snakes) {
+	BOOST_FOREACH(Snake& snake, snakes) {
 		evolveSnake(snake, gradient, ON_CONVERGENCE_GO_FINER);
 	}
 	if (dbg) { 
@@ -167,11 +166,11 @@ TextLineRefiner::refine(
 
 	// Convert from snakes back to polylines.
 	int i = -1;
-	for (std::vector<QPointF>& polyline: polylines) {
+	BOOST_FOREACH(std::vector<QPointF>& polyline, polylines) {
 		++i;
 		Snake const& snake = snakes[i];
 		polyline.clear();
-		for (SnakeNode const& node: snake.nodes) {
+		BOOST_FOREACH(SnakeNode const& node, snake.nodes) {
 			polyline.push_back(node.center);
 		}
 	}
@@ -319,7 +318,7 @@ TextLineRefiner::calcFrenetFrames(
 	}
 
 	// Calculate normals and make sure they point down.
-	for (FrenetFrame& frame: frenet_frames) {
+	BOOST_FOREACH(FrenetFrame& frame, frenet_frames) {
 		frame.unitDownNormal = Vec2f(frame.unitTangent[1], -frame.unitTangent[0]);
 		if (frame.unitDownNormal.dot(unit_down_vec) < 0) {
 			frame.unitDownNormal = -frame.unitDownNormal;
@@ -429,7 +428,7 @@ TextLineRefiner::visualizeSnakes(std::vector<Snake> const& snakes, Grid<float> c
 	bottom_pen.setWidthF(1.5);
 	
 	QPen middle_pen(QColor(255, 0, 255));
-    middle_pen.setWidthF(1.5);
+	middle_pen.setWidth(1.5);
 
 	QBrush knot_brush(QColor(255, 255, 0, 180));
 	painter.setBrush(knot_brush);
@@ -437,7 +436,7 @@ TextLineRefiner::visualizeSnakes(std::vector<Snake> const& snakes, Grid<float> c
 	QRectF knot_rect(0, 0, 7, 7);
 	std::vector<FrenetFrame> frenet_frames;
 
-	for (Snake const& snake: snakes) {
+	BOOST_FOREACH(Snake const& snake, snakes) {
 		SnakeLength const snake_length(snake);
 		calcFrenetFrames(frenet_frames, snake, snake_length, m_unitDownVec);
 		QVector<QPointF> top_polyline;
@@ -466,7 +465,7 @@ TextLineRefiner::visualizeSnakes(std::vector<Snake> const& snakes, Grid<float> c
 
 		// Draw knots.
 		painter.setPen(Qt::NoPen);
-		for (QPointF const& pt: middle_polyline) {
+		BOOST_FOREACH(QPointF const& pt, middle_polyline) {
 			knot_rect.moveCenter(pt);
 			painter.drawEllipse(knot_rect);
 		}
@@ -614,7 +613,7 @@ TextLineRefiner::Optimizer::tangentMovement(Snake& snake, Grid<float> const& gra
 			}
 
 			// Now find the best step for the previous node to combine with.
-			for (uint32_t prev_step_idx: paths) {
+			BOOST_FOREACH(uint32_t prev_step_idx, paths) {
 				Step const& prev_step = step_storage[prev_step_idx];
 				float const cost = base_cost + prev_step.pathCost +
 					calcElasticityEnergy(step.node, prev_step.node, m_snakeLength.avgSegmentLength());
@@ -636,7 +635,7 @@ TextLineRefiner::Optimizer::tangentMovement(Snake& snake, Grid<float> const& gra
 	// Find the best overall path.
 	uint32_t best_path_idx = ~uint32_t(0);
 	float best_cost = NumericTraits<float>::max();
-	for (uint32_t last_step_idx: paths) {
+	BOOST_FOREACH(uint32_t last_step_idx, paths) {
 		Step const& step = step_storage[last_step_idx];
 		if (step.pathCost < best_cost) {
 			best_cost = step.pathCost;
@@ -727,7 +726,7 @@ TextLineRefiner::Optimizer::normalMovement(Snake& snake, Grid<float> const& grad
 			float const base_cost = calcExternalEnergy(gradient, step.node, down_normal);
 
 			// Now find the best step for the previous node to combine with.
-			for (uint32_t prev_step_idx: paths) {
+			BOOST_FOREACH(uint32_t prev_step_idx, paths) {
 				Step const& prev_step = step_storage[prev_step_idx];
 				Step const& prev_prev_step = step_storage[prev_step.prevStepIdx];
 
@@ -751,7 +750,7 @@ TextLineRefiner::Optimizer::normalMovement(Snake& snake, Grid<float> const& grad
 	// Find the best overall path.
 	uint32_t best_path_idx = ~uint32_t(0);
 	float best_cost = NumericTraits<float>::max();
-	for (uint32_t last_step_idx: paths) {
+	BOOST_FOREACH(uint32_t last_step_idx, paths) {
 		Step const& step = step_storage[last_step_idx];
 		if (step.pathCost < best_cost) {
 			best_cost = step.pathCost;
