@@ -58,12 +58,11 @@
 #include <QPen>
 #include <QColor>
 #include <QtGlobal>
-#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
 #include <boost/lambda/if.hpp>
-#endif
 #include <algorithm>
 #include <set>
 #include <map>
@@ -154,8 +153,8 @@ TextLineTracer::trace(
 	vert_bounds.second = to_orig.map(vert_bounds.second);
 	output.setVerticalBounds(vert_bounds.first, vert_bounds.second);
 
-	for (std::vector<QPointF>& polyline: polylines) {
-		for (QPointF& pt: polyline) {
+	BOOST_FOREACH(std::vector<QPointF>& polyline, polylines) {
+		BOOST_FOREACH(QPointF& pt, polyline) {
 			pt = to_orig.map(pt);
 		}
 		output.addHorizontalCurve(polyline);
@@ -246,7 +245,7 @@ TextLineTracer::isCurvatureConsistent(std::vector<QPointF> const& polyline)
 		prev_normal_sqlen = next_segment_sqlen;
 	}
 
-    return !(significant_positive && significant_negative);
+	return !(significant_positive && significant_positive);
 }
 
 bool
@@ -474,7 +473,7 @@ TextLineTracer::extractTextLines(
 
 	post_binarization.release(); // Save memory.
 
-	for (QPoint const seed: seeds) {
+	BOOST_FOREACH(QPoint const seed, seeds) {
 		std::vector<QPointF> polyline;
 		
 		{
@@ -676,7 +675,7 @@ TextLineTracer::visualizeMidLineSeeds(
 	painter.setPen(Qt::NoPen);
 	painter.setBrush(QColor(0x2d, 0x00, 0x6d, 255));
 	QRectF rect(0, 0, 7, 7);
-	for (QPoint const pt: seeds) {
+	BOOST_FOREACH(QPoint const pt, seeds) {
 		rect.moveCenter(pt + QPointF(0.5, 0.5));
 		painter.drawEllipse(rect);
 	}
@@ -696,7 +695,7 @@ TextLineTracer::visualizePolylines(
 	pen.setWidthF(3.0);
 	painter.setPen(pen);
 
-	for (std::vector<QPointF> const& polyline: polylines) {
+	BOOST_FOREACH(std::vector<QPointF> const& polyline, polylines) {
 		if (!polyline.empty()) {
 			painter.drawPolyline(&polyline[0], polyline.size());
 		}
