@@ -39,10 +39,9 @@
 #include <QColor>
 #include <QtGlobal>
 #include <QDebug>
-#ifndef Q_MOC_RUN
+#include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
-#endif
 #include <limits>
 #include <algorithm>
 #include <math.h>
@@ -260,7 +259,7 @@ TopBottomEdgeTracer::trace(
 	std::vector<std::vector<QPointF> > snakes;
 	snakes.reserve(endpoints1.size());
 	
-	for (QPoint endpoint: endpoints1) {
+	BOOST_FOREACH(QPoint endpoint, endpoints1) {
 		snakes.push_back(pathToSnake(grid, endpoint));
 		Vec2f const dir(downTheHillDirection(downscaled.rect(), snakes.back(), avg_bounds_dir));
 		downTheHillSnake(snakes.back(), grid, dir);
@@ -270,7 +269,7 @@ TopBottomEdgeTracer::trace(
 		dbg->add(visualizeSnakes(background, snakes, bounds), "down_the_hill_snakes");
 	}
 
-	for (std::vector<QPointF>& snake: snakes) {
+	BOOST_FOREACH(std::vector<QPointF>& snake, snakes) {
 		Vec2f const dir(-downTheHillDirection(downscaled.rect(), snake, avg_bounds_dir));
 		upTheHillSnake(snake, grid, dir);
 	}
@@ -281,8 +280,8 @@ TopBottomEdgeTracer::trace(
 
 	// Convert snakes back to the original coordinate system.
 	QTransform const upscaling_xform(downscaling_xform.inverted());
-	for (std::vector<QPointF>& snake: snakes) {
-		for (QPointF& pt: snake) {
+	BOOST_FOREACH(std::vector<QPointF>& snake, snakes) {
+		BOOST_FOREACH(QPointF& pt, snake) {
 			pt = upscaling_xform.map(pt);
 		}
 		output.addHorizontalCurve(snake);
@@ -621,7 +620,7 @@ TopBottomEdgeTracer::locateBestPathEndpoints(Grid<GridNode> const& grid, QLineF
 		// Find the closest path.
 		Path* closest_path = 0;
 		int closest_sqdist = std::numeric_limits<int>::max();
-		for (Path& path: best_paths) {
+		BOOST_FOREACH(Path& path, best_paths) {
 			QPoint const delta(path.pt - pt);
 			int const sqdist = delta.x() * delta.x() + delta.y() * delta.y();
 			if (sqdist < closest_sqdist) {
@@ -643,7 +642,7 @@ TopBottomEdgeTracer::locateBestPathEndpoints(Grid<GridNode> const& grid, QLineF
 			best_paths.push_back(Path(pt, node->pathCost));
 		} else {
 			// Find the one to kick out (if any).
-			for (Path& path: best_paths) {
+			BOOST_FOREACH(Path& path, best_paths) {
 				if (node->pathCost < path.cost) {
 					path = Path(pt, node->pathCost);
 					break;
@@ -654,7 +653,7 @@ TopBottomEdgeTracer::locateBestPathEndpoints(Grid<GridNode> const& grid, QLineF
 
 	std::vector<QPoint> best_endpoints;
 
-	for (Path const& path: best_paths) {
+	BOOST_FOREACH(Path const& path, best_paths) {
 		if (path.cost < 0.95f) {
 			best_endpoints.push_back(path.pt);
 		}
@@ -784,7 +783,7 @@ TopBottomEdgeTracer::downTheHillDirection(
 
 	// Take the centroid of a snake.
 	QPointF centroid;
-	for (QPointF const& pt: snake) {
+	BOOST_FOREACH(QPointF const& pt, snake) {
 		centroid += pt;
 	}
 	centroid /= snake.size();
@@ -865,7 +864,7 @@ TopBottomEdgeTracer::downTheHillSnake(
 				float best_cost = NumericTraits<float>::max();
 				uint32_t best_prev_step_idx = step.prevStepIdx;
 
-				for (uint32_t prev_step_idx: paths) {
+				BOOST_FOREACH(uint32_t prev_step_idx, paths) {
 					Step const& prev_step = step_storage[prev_step_idx];
 					float cost = prev_step.pathCost + step.pathCost;
 
@@ -918,7 +917,7 @@ TopBottomEdgeTracer::downTheHillSnake(
 		
 		uint32_t best_path_idx = ~uint32_t(0);
 		float best_cost = NumericTraits<float>::max();
-		for (uint32_t last_step_idx: paths) {
+		BOOST_FOREACH(uint32_t last_step_idx, paths) {
 			Step const& step = step_storage[last_step_idx];
 			if (step.pathCost < best_cost) {
 				best_cost = step.pathCost;
@@ -1003,7 +1002,7 @@ TopBottomEdgeTracer::upTheHillSnake(
 				float best_cost = NumericTraits<float>::max();
 				uint32_t best_prev_step_idx = step.prevStepIdx;
 
-				for (uint32_t prev_step_idx: paths) {
+				BOOST_FOREACH(uint32_t prev_step_idx, paths) {
 					Step const& prev_step = step_storage[prev_step_idx];
 					float cost = prev_step.pathCost + step.pathCost;
 
@@ -1056,7 +1055,7 @@ TopBottomEdgeTracer::upTheHillSnake(
 		
 		uint32_t best_path_idx = ~uint32_t(0);
 		float best_cost = NumericTraits<float>::max();
-		for (uint32_t last_step_idx: paths) {
+		BOOST_FOREACH(uint32_t last_step_idx, paths) {
 			Step const& step = step_storage[last_step_idx];
 			if (step.pathCost < best_cost) {
 				best_cost = step.pathCost;
@@ -1247,7 +1246,7 @@ TopBottomEdgeTracer::visualizePaths(
 		+grid_stride - 1, +grid_stride, +grid_stride + 1
 	};
 
-	for (QPoint const path_endpoint: path_endpoints) {
+	BOOST_FOREACH(QPoint const path_endpoint, path_endpoints) {
 		int grid_offset = path_endpoint.x() + path_endpoint.y() * grid_stride;
 		int canvas_offset = path_endpoint.x() + path_endpoint.y() * canvas_stride;
 		for (;;) {
@@ -1283,8 +1282,8 @@ TopBottomEdgeTracer::visualizePaths(
 	uint32_t* const canvas_data = (uint32_t*)canvas.bits();
 	int const canvas_stride = canvas.bytesPerLine() / 4;
 	
-	for (std::vector<QPoint> const& path: paths) {
-		for (QPoint pt: path) {
+	BOOST_FOREACH(std::vector<QPoint> const& path, paths) {
+		BOOST_FOREACH(QPoint pt, path) {
 			canvas_data[pt.x() + pt.y() * canvas_stride] = 0x00ff0000;
 		}
 	}
@@ -1317,7 +1316,7 @@ TopBottomEdgeTracer::visualizeSnakes(
 
 	QRectF knot_rect(0, 0, 7, 7);
 
-	for (std::vector<QPointF> const& snake: snakes) {
+	BOOST_FOREACH(std::vector<QPointF> const& snake, snakes) {
 		if (snake.empty()) {
 			continue;
 		}
@@ -1325,7 +1324,7 @@ TopBottomEdgeTracer::visualizeSnakes(
 		painter.setPen(snake_pen);
 		painter.drawPolyline(&snake[0], snake.size());
 		painter.setPen(Qt::NoPen);
-		for (QPointF const& knot: snake) {
+		BOOST_FOREACH(QPointF const& knot, snake) {
 			knot_rect.moveCenter(knot);
 			painter.drawEllipse(knot_rect);
 		}
@@ -1353,7 +1352,7 @@ TopBottomEdgeTracer::visualizePolylines(
 	polyline_pen.setWidthF(4.0);
 	painter.setPen(polyline_pen);
 
-	for (std::vector<QPointF> const& polyline: polylines) {
+	BOOST_FOREACH(std::vector<QPointF> const& polyline, polylines) {
 		if (polyline.empty()) {
 			continue;
 		}
