@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class ThumbnailCollector : public AbstractFilterDataCollector
 public:
 	virtual void processThumbnail(std::auto_ptr<QGraphicsItem>) = 0;
 	
-	virtual ThumbnailPixmapCache& thumbnailCache() = 0;
+	virtual IntrusivePtr<ThumbnailPixmapCache> thumbnailCache() = 0;
 	
 	virtual QSizeF maxLogicalThumbSize() const = 0;
 };
