@@ -72,6 +72,12 @@ Filter::getView() const
 	return IMAGE_VIEW;
 }
 
+void
+Filter::performRelinking(AbstractRelinker const& relinker)
+{
+	m_ptrSettings->performRelinking(relinker);
+}
+
 void
 Filter::preUpdateUI(FilterUiInterface* ui, PageId const& page_id)
 {
