@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "OptionsWidget.h"
 #include "OptionsWidget.h.moc"
 #include "Filter.h"
 #include "ApplyDialog.h"
 #include "Settings.h"
-#include "PageSequence.h"
+#include "ProjectPages.h"
 #include "ImageId.h"
 #include "PageId.h"
 #include <boost/foreach.hpp>
@@ -32,10 +33,8 @@ namespace fix_orientation
 
 OptionsWidget::OptionsWidget(
 	IntrusivePtr<Settings> const& settings,
-	IntrusivePtr<PageSequence> const& pages,
 	PageSelectionAccessor const& page_selection_accessor)
 :	m_ptrSettings(settings),
-	m_ptrPages(pages),
 	m_pageSelectionAccessor(page_selection_accessor)
 {
 	setupUi(this);
@@ -51,8 +50,10 @@ OptionsWidget::~OptionsWidget()
 }
 
 void
-OptionsWidget::preUpdateUI(OrthogonalRotation const rotation)
+OptionsWidget::preUpdateUI(
+	PageId const& page_id, OrthogonalRotation const rotation)
 {
+	m_pageId = page_id;
 	m_rotation = rotation;
 	setRotationPixmap();
 }
@@ -89,13 +90,17 @@ void
 OptionsWidget::showApplyToDialog()
 {
 	ApplyDialog* dialog = new ApplyDialog(
-		this, m_ptrPages, m_pageSelectionAccessor
+		this, m_pageId, m_pageSelectionAccessor
 	);
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
 	connect(
 		dialog, SIGNAL(appliedTo(std::set<PageId> const&)),
 		this, SLOT(appliedTo(std::set<PageId> const&))
 	);
+	connect(
+		dialog, SIGNAL(appliedToAllPages(std::set<PageId> const&)),
+		this, SLOT(appliedToAllPages(std::set<PageId> const&))
+	);
 	dialog->show();
 }
 
@@ -107,16 +112,18 @@ OptionsWidget::appliedTo(std::set<PageId> const& pages)
 	}
 	
 	m_ptrSettings->applyRotation(pages, m_rotation);
-	
-	if (int(pages.size()) > m_ptrPages->numImages() / 2) {
-		emit invalidateAllThumbnails();
-	} else {
-		BOOST_FOREACH(PageId const& page_id, pages) {
-			emit invalidateThumbnail(page_id);
-		}
+	BOOST_FOREACH(PageId const& page_id, pages) {
+		emit invalidateThumbnail(page_id);
 	}
 }
 
+void
+OptionsWidget::appliedToAllPages(std::set<PageId> const& pages)
+{
+	m_ptrSettings->applyRotation(pages, m_rotation);
+	emit invalidateAllThumbnails();
+}
+
 void
 OptionsWidget::setRotation(OrthogonalRotation const rotation)
 {
@@ -127,11 +134,10 @@ OptionsWidget::setRotation(OrthogonalRotation const rotation)
 	m_rotation = rotation;
 	setRotationPixmap();
 	
-	ImageId const image_id(m_ptrPages->curImage());
-	m_ptrSettings->applyRotation(image_id, rotation);
+	m_ptrSettings->applyRotation(m_pageId.imageId(), rotation);
 	
 	emit rotated(rotation);
-	emit invalidateThumbnail(PageId(image_id));
+	emit invalidateThumbnail(m_pageId);
 }
 
 void
