@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,8 +46,7 @@ public:
 	
 	void process(
 		PageInfo const& page_info, AbstractFilterDataCollector* collector,
-		ImageTransformation const& xform,
-		QPolygonF const& content_rect_phys, QPolygonF const& page_rect_phys);
+		ImageTransformation const& xform, QPolygonF const& content_rect_phys);
 private:
 	IntrusivePtr<Settings> m_ptrSettings;
 	OutputFileNameGenerator m_outFileNameGen;
