@@ -27,12 +27,7 @@ namespace output
 class DewarpingMode
 {
 public:
-	enum Mode { OFF, AUTO, MANUAL 
-//begin of modified by monday2000
-//Marginal_Dewarping
-				, MARGINAL
-//end of modified by monday2000
-	};
+	enum Mode { OFF, AUTO, MANUAL };
 
 	DewarpingMode(Mode mode = OFF) : m_mode(mode) {}
 
