@@ -22,17 +22,24 @@
 #include "imageproc/Connectivity.h"
 #include "Dpi.h"
 #include "ColorParams.h"
+#include "DepthPerception.h"
 #include "DespeckleLevel.h"
+#include "DewarpingMode.h"
+#include "ImageTransformation.h"
+#include <boost/function.hpp>
 #include <QSize>
 #include <QRect>
 #include <QTransform>
 #include <QColor>
+#include <QPointF>
+#include <QLineF>
 #include <QPolygonF>
+#include <vector>
+#include <utility>
 #include <stdint.h>
 
 class TaskStatus;
 class DebugImages;
-class ImageTransformation;
 class FilterData;
 class ZoneSet;
 class QSize;
@@ -45,6 +52,12 @@ namespace imageproc
 	class GrayImage;
 }
 
+namespace dewarping
+{
+	class DistortionModel;
+	class CylindricalSurfaceDewarper;
+}
+
 namespace output
 {
 
@@ -54,9 +67,8 @@ public:
 	OutputGenerator(
 		Dpi const& dpi, ColorParams const& color_params,
 		DespeckleLevel despeckle_level,
-		ImageTransformation const& pre_xform,
-		QPolygonF const& content_rect_phys,
-		QPolygonF const& page_rect_phys);
+		ImageTransformation const& xform,
+		QPolygonF const& content_rect_phys);
 	
 	/**
 	 * \brief Produce the output image.
@@ -65,6 +77,7 @@ public:
 	 * \param input The input image plus data produced by previous stages.
 	 * \param picture_zones A set of manual picture zones.
 	 * \param fill_zones A set of manual fill zones.
+	 * \param distortion_model A curved rectangle.
 	 * \param auto_picture_mask If provided, the auto-detected picture mask
 	 *        will be written there.  It would only happen if automatic picture
 	 *        detection actually took place.  Otherwise, nothing will be
@@ -84,15 +97,13 @@ public:
 	QImage process(
 		TaskStatus const& status, FilterData const& input,
 		ZoneSet const& picture_zones, ZoneSet const& fill_zones,
+		DewarpingMode dewarping_mode,
+		dewarping::DistortionModel& distortion_model,
+		DepthPerception const& depth_perception,
 		imageproc::BinaryImage* auto_picture_mask = 0,
 		imageproc::BinaryImage* speckles_image = 0,
 		DebugImages* dbg = 0) const;
 	
-	/**
-	 * Returns the transformation from original to output image coordinates.
-	 */
-	QTransform toOutput() const;
-
 	QSize outputImageSize() const;
 	
 	/**
@@ -100,24 +111,64 @@ public:
 	 */
 	QRect outputContentRect() const;
 private:
-	QImage processAsIs(FilterData const& input,
-		TaskStatus const& status, DebugImages* dbg = 0) const;
-	
 	QImage processImpl(
+		TaskStatus const& status, FilterData const& input,
+		ZoneSet const& picture_zones, ZoneSet const& fill_zones,
+		DewarpingMode dewarping_mode,
+		dewarping::DistortionModel& distortion_model,
+		DepthPerception const& depth_perception,
+		imageproc::BinaryImage* auto_picture_mask = 0,
+		imageproc::BinaryImage* speckles_image = 0,
+		DebugImages* dbg = 0) const;
+
+	QImage processAsIs(
+		FilterData const& input, TaskStatus const& status,
+		ZoneSet const& fill_zones,
+		DepthPerception const& depth_perception,
+		DebugImages* dbg = 0) const;
+
+	QImage processWithoutDewarping(
 		TaskStatus const& status, FilterData const& input,
 		ZoneSet const& picture_zones, ZoneSet const& fill_zones,
 		imageproc::BinaryImage* auto_picture_mask = 0,
 		imageproc::BinaryImage* speckles_image = 0,
 		DebugImages* dbg = 0) const;
+
+	QImage processWithDewarping(
+		TaskStatus const& status, FilterData const& input,
+		ZoneSet const& picture_zones, ZoneSet const& fill_zones,
+		DewarpingMode dewarping_mode,
+		dewarping::DistortionModel& distortion_model,
+		DepthPerception const& depth_perception,
+		imageproc::BinaryImage* auto_picture_mask = 0,
+		imageproc::BinaryImage* speckles_image = 0,
+		DebugImages* dbg = 0) const;
 	
+	void setupTrivialDistortionModel(dewarping::DistortionModel& distortion_model) const;
+
+	static dewarping::CylindricalSurfaceDewarper createDewarper(
+		dewarping::DistortionModel const& distortion_model,
+		QTransform const& distortion_model_to_target, double depth_perception);
+
+	QImage dewarp(
+		QTransform const& orig_to_src, QImage const& src,
+		QTransform const& src_to_output, dewarping::DistortionModel const& distortion_model,
+		DepthPerception const& depth_perception, QColor const& bg_color) const;
+
 	static QSize from300dpi(QSize const& size, Dpi const& target_dpi);
 	
 	static QSize to300dpi(QSize const& size, Dpi const& source_dpi);
 	
-	static QImage normalizeIlluminationGray(
+	static QImage convertToRGBorRGBA(QImage const& src);
+
+	static void fillMarginsInPlace(
+		QImage& image, QPolygonF const& content_poly, QColor const& color);
+
+	static imageproc::GrayImage normalizeIlluminationGray(
 		TaskStatus const& status,
 		QImage const& input, QPolygonF const& area_to_consider,
-		QTransform const& xform, QRect const& target_rect, DebugImages* dbg);
+		QTransform const& xform, QRect const& target_rect,
+		imageproc::GrayImage* background = 0, DebugImages* dbg = 0);
 	
 	static imageproc::GrayImage detectPictures(
 		imageproc::GrayImage const& input_300dpi, TaskStatus const& status,
@@ -135,6 +186,13 @@ private:
 	imageproc::BinaryThreshold adjustThreshold(
 		imageproc::BinaryThreshold threshold) const;
 	
+	imageproc::BinaryThreshold calcBinarizationThreshold(
+		QImage const& image, imageproc::BinaryImage const& mask) const;
+
+	imageproc::BinaryThreshold calcBinarizationThreshold(
+		QImage const& image, QPolygonF const& crop_area,
+		imageproc::BinaryImage const* mask = 0) const;
+
 	imageproc::BinaryImage binarize(
 		QImage const& image, imageproc::BinaryImage const& mask) const;
 	
@@ -162,7 +220,7 @@ private:
 	static unsigned char calcDominantBackgroundGrayLevel(QImage const& img);
 	
 	static QImage normalizeIllumination(QImage const& gray_input, DebugImages* dbg);
-	
+
 	QImage transformAndNormalizeIllumination(
 		QImage const& gray_input, DebugImages* dbg,
 		QImage const* morph_background = 0) const;
@@ -171,41 +229,34 @@ private:
 		QImage const& gray_input, DebugImages* dbg,
 		QImage const* morph_background = 0) const;
 
+	void applyFillZonesInPlace(QImage& img, ZoneSet const& zones,
+		boost::function<QPointF(QPointF const&)> const& orig_to_output) const;
+
 	void applyFillZonesInPlace(QImage& img, ZoneSet const& zones) const;
 
+	void applyFillZonesInPlace(imageproc::BinaryImage& img, ZoneSet const& zones,
+		boost::function<QPointF(QPointF const&)> const& orig_to_output) const;
+
 	void applyFillZonesInPlace(imageproc::BinaryImage& img, ZoneSet const& zones) const;
 	
 	Dpi m_dpi;
 	ColorParams m_colorParams;
-	QPolygonF m_pageRectPhys;
 	
 	/**
-	 * Transformation from the input image coordinates to coordinates
-	 * of the output image before it's cropped.  This transformation
-	 * includes all transformations from the ImageTransformation
-	 * passed to a constructor, plus scaling to produce the
-	 * desired output DPI.
+	 * Transformation from the input to the output image coordinates.
 	 */
-	QTransform m_toUncropped;
-	
+	ImageTransformation m_xform;
+
 	/**
-	 * The content rectangle in m_toUncropped coordinates.
+	 * The rectangle corresponding to the output image.
+	 * The top-left corner will always be at (0, 0).
+	 */
+	QRect m_outRect;
+
+	/**
+	 * The content rectangle in output image coordinates.
 	 */
 	QRect m_contentRect;
-	
-	/**
-	 * The cropping rectangle in m_toUncropped coordinates.
-	 * The cropping rectangle is the content rect plus margins.
-	 */
-	QRect m_cropRect;
-	
-	/**
-	 * The bounding rectangle of a polygon that represents
-	 * the page boundaries.  The polygon is usually formed
-	 * by image edges and a split line.  This rectangle is
-	 * in m_toUncropped coordinates.
-	 */
-	QRect m_fullPageRect;
 
 	DespeckleLevel m_despeckleLevel;
 };
