@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2009  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,8 @@ public:
 	OutputParams(OutputImageParams const& output_image_params,
 		OutputFileParams const& output_file_params,
 		OutputFileParams const& automask_file_params,
-		ZoneSet const& zones);
+		OutputFileParams const& speckles_file_params,
+		ZoneSet const& picture_zones, ZoneSet const& fill_zones);
 	
 	explicit OutputParams(QDomElement const& el);
 	
@@ -48,12 +49,18 @@ public:
 
 	OutputFileParams const& automaskFileParams() const { return m_automaskFileParams; }
 
-	ZoneSet const& zones() const { return m_zones; }
+	OutputFileParams const& specklesFileParams() const { return m_specklesFileParams; }
+
+	ZoneSet const& pictureZones() const { return m_pictureZones; }
+
+	ZoneSet const& fillZones() const { return m_fillZones; }
 private:
 	OutputImageParams m_outputImageParams;
 	OutputFileParams m_outputFileParams;
 	OutputFileParams m_automaskFileParams;
-	ZoneSet m_zones;
+	OutputFileParams m_specklesFileParams;
+	ZoneSet m_pictureZones;
+	ZoneSet m_fillZones;
 };
 
 } // namespace output
