@@ -96,7 +96,7 @@ private:
 
 
 PictureZoneEditor::PictureZoneEditor(
-	QImage const& image, QImage const& downscaled_image,
+	QImage const& image, ImagePixmapUnion const& downscaled_image,
 	imageproc::BinaryImage const& picture_mask,
 	QTransform const& image_to_virt, QPolygonF const& virt_display_area,
 	PageId const& page_id, IntrusivePtr<Settings> const& settings)
@@ -378,7 +378,7 @@ PictureZoneEditor::MaskTransformTask::operator()()
 	QImage gray_mask(
 		transformToGray(
 			m_origMask.toQImage(), m_xform, target_rect,
-			Qt::black, true, QSizeF(0.0, 0.0)
+			OutsidePixels::assumeWeakColor(Qt::black), QSizeF(0.0, 0.0)
 		)
 	);
 
