@@ -18,7 +18,6 @@
 
 #include "PictureZonePropFactory.h"
 #include "PictureLayerProperty.h"
-#include "ZoneCategoryProperty.h"
 
 namespace output
 {
@@ -26,7 +25,6 @@ namespace output
 PictureZonePropFactory::PictureZonePropFactory()
 {
 	PictureLayerProperty::registerIn(*this);
-	ZoneCategoryProperty::registerIn(*this);
 }
 
 } // namespace output
