@@ -22,7 +22,6 @@
 #include "ImageViewTab.h"
 #include <QTabWidget>
 #include <map>
-#include <QAbstractSlider>
 
 namespace output
 {
@@ -42,10 +41,6 @@ private slots:
 	void tabChangedSlot(int idx);
 private:
 	std::map<QWidget*, ImageViewTab> m_registry;
-    int m_previouslySelectedTabId;
-    qreal m_stored_zoom_lvl;
-    QAbstractSlider* m_stored_hrz_slider;
-    QAbstractSlider* m_stored_vrt_slider;
 };
 
 } // namespace output
