@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,45 +17,32 @@
 */
 
 #include "Utils.h"
-#include "PageId.h"
 #include "Dpi.h"
 #include <QString>
 #include <QTransform>
-#include <QFileInfo>
 #include <QDir>
 
 namespace output
 {
 
-QString
-Utils::outFilePath(
-	PageId const& page_id, int const page_num, QString const& out_dir)
-{
-	QString const base_file_name(
-		QFileInfo(page_id.imageId().filePath()).completeBaseName()
-	);
-	
-	QString const padded_number(
-		QString::fromAscii("%1").arg(
-			QString::number(page_num + 1), 4, QChar('0')
-		)
-	);
-	
-	QString const out_path(
-		QString::fromAscii("%1/%2_%3.tiff").arg(
-			out_dir, padded_number, base_file_name
-		)
-	);
-	
-	return out_path;
-}
-
 QString
 Utils::automaskDir(QString const& out_dir)
 {
 	return QDir(out_dir).absoluteFilePath("cache/automask");
 }
 
+QString
+Utils::predespeckleDir(QString const& out_dir)
+{
+	return QDir(out_dir).absoluteFilePath("cache/predespeckle");
+}
+
+QString
+Utils::specklesDir(QString const& out_dir)
+{
+	return QDir(out_dir).absoluteFilePath("cache/speckles");
+}
+
 QTransform
 Utils::scaleFromToDpi(Dpi const& from, Dpi const& to)
 {
