@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,12 +16,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "OptionsWidget.h"
 #include "OptionsWidget.h.moc"
 #include "Settings.h"
 #include "ApplyDialog.h"
 #include "../../Utils.h"
 #include "ScopedIncDec.h"
-#include "PageSequence.h"
 #include "PageInfo.h"
 #include "PageId.h"
 #include "imageproc/Constants.h"
@@ -37,10 +37,8 @@ namespace page_layout
 
 OptionsWidget::OptionsWidget(
 	IntrusivePtr<Settings> const& settings,
-	IntrusivePtr<PageSequence> const& pages,
 	PageSelectionAccessor const& page_selection_accessor)
 :	m_ptrSettings(settings),
-	m_ptrPages(pages),
 	m_pageSelectionAccessor(page_selection_accessor),
 	m_mmToUnit(1.0),
 	m_unitToMM(1.0),
@@ -56,8 +54,6 @@ OptionsWidget::OptionsWidget(
 	);
 	
 	setupUi(this);
-	widestPageLink->setText(Utils::richTextForLink(widestPageLink->text()));
-	tallestPageLink->setText(Utils::richTextForLink(tallestPageLink->text()));
 	updateLinkDisplay(topBottomLink, m_topBottomLinked);
 	updateLinkDisplay(leftRightLink, m_leftRightLinked);
 	enableDisableAlignmentButtons();
@@ -135,14 +131,6 @@ OptionsWidget::OptionsWidget(
 		alignWithOthersCB, SIGNAL(toggled(bool)),
 		this, SLOT(alignWithOthersToggled())
 	);
-	connect(
-		widestPageLink, SIGNAL(linkActivated(QString const&)),
-		this, SLOT(goToWidestPage())
-	);
-	connect(
-		tallestPageLink, SIGNAL(linkActivated(QString const&)),
-		this, SLOT(goToTallestPage())
-	);
 	connect(
 		applyAlignmentBtn, SIGNAL(clicked()),
 		this, SLOT(showApplyAlignmentDialog())
@@ -162,8 +150,10 @@ OptionsWidget::~OptionsWidget()
 }
 
 void
-OptionsWidget::preUpdateUI(Margins const& margins_mm, Alignment const& alignment)
+OptionsWidget::preUpdateUI(
+	PageId const& page_id, Margins const& margins_mm, Alignment const& alignment)
 {
+	m_pageId = page_id;
 	m_marginsMM = margins_mm;
 	m_alignment = alignment;
 	
@@ -182,8 +172,8 @@ OptionsWidget::preUpdateUI(Margins const& margins_mm, Alignment const& alignment
 	
 	enableDisableAlignmentButtons();
 	
-	m_leftRightLinked = true;
-	m_topBottomLinked = true;
+	m_leftRightLinked = (margins_mm.left() == margins_mm.right());
+	m_topBottomLinked = (margins_mm.top() == margins_mm.bottom());
 	updateLinkDisplay(topBottomLink, m_topBottomLinked);
 	updateLinkDisplay(leftRightLink, m_leftRightLinked);
 	
@@ -310,29 +300,11 @@ OptionsWidget::alignmentButtonClicked()
 	emit alignmentChanged(m_alignment);
 }
 
-void
-OptionsWidget::goToWidestPage()
-{
-	PageId const page_id(m_ptrSettings->findWidestPage());
-	if (!page_id.isNull()) {
-		emit goToPage(page_id);
-	}
-}
-
-void
-OptionsWidget::goToTallestPage()
-{
-	PageId const page_id(m_ptrSettings->findTallestPage());
-	if (!page_id.isNull()) {
-		emit goToPage(page_id);
-	}
-}
-
 void
 OptionsWidget::showApplyMarginsDialog()
 {
 	ApplyDialog* dialog = new ApplyDialog(
-		this, m_ptrPages, m_pageSelectionAccessor
+		this, m_pageId, m_pageSelectionAccessor
 	);
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
 	dialog->setWindowTitle(tr("Apply Margins"));
@@ -347,7 +319,7 @@ void
 OptionsWidget::showApplyAlignmentDialog()
 {
 	ApplyDialog* dialog = new ApplyDialog(
-		this, m_ptrPages, m_pageSelectionAccessor
+		this, m_pageId, m_pageSelectionAccessor
 	);
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
 	dialog->setWindowTitle(tr("Apply Alignment"));
