@@ -22,6 +22,8 @@
 #include "Params.h"
 #include "Margins.h"
 #include "Alignment.h"
+#include "RelinkablePath.h"
+#include "AbstractRelinker.h"
 #include <QSizeF>
 #include <QMutex>
 #include <QMutexLocker>
@@ -115,6 +117,8 @@ public:
 	~Impl();
 	
 	void clear();
+
+	void performRelinking(AbstractRelinker const& relinker);
 	
 	void removePagesMissingFrom(PageSequence const& pages);
 	
@@ -221,6 +225,12 @@ Settings::clear()
 	return m_ptrImpl->clear();
 }
 
+void
+Settings::performRelinking(AbstractRelinker const& relinker)
+{
+	m_ptrImpl->performRelinking(relinker);
+}
+
 void
 Settings::removePagesMissingFrom(PageSequence const& pages)
 {
@@ -370,6 +380,22 @@ Settings::Impl::clear()
 	m_items.clear();
 }
 
+void
+Settings::Impl::performRelinking(AbstractRelinker const& relinker)
+{
+	QMutexLocker locker(&m_mutex);
+	Container new_items;
+
+	BOOST_FOREACH(Item const& item, m_unorderedItems) {
+		RelinkablePath const old_path(item.pageId.imageId().filePath(), RelinkablePath::File);
+		Item new_item(item);
+		new_item.pageId.imageId().setFilePath(relinker.substitutionPathFor(old_path));
+		new_items.insert(new_item);
+	}
+
+	m_items.swap(new_items);
+}
+
 void
 Settings::Impl::removePagesMissingFrom(PageSequence const& pages)
 {
@@ -638,7 +664,7 @@ Settings::Impl::getAggregateHardSizeMM(
 				width = hard_size_mm.width();
 			} else {
 				width = std::max(
-					hard_size_mm.width(), it->influenceHardWidthMM()
+					hard_size_mm.width(), qreal(it->influenceHardWidthMM())
 				);
 			}
 		}
@@ -656,7 +682,7 @@ Settings::Impl::getAggregateHardSizeMM(
 				height = hard_size_mm.height();
 			} else {
 				height = std::max(
-					hard_size_mm.height(), it->influenceHardHeightMM()
+					hard_size_mm.height(), qreal(it->influenceHardHeightMM())
 				);
 			}
 		}
