@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@
 #include <QTransform>
 #include <QObject>
 
+#include "CommandLine.h"
+
 namespace page_layout
 {
 
@@ -117,10 +119,14 @@ Task::process(
 				params, agg_hard_size_after
 			)
 		);
+
+		ImageTransformation new_xform(data.xform());
+		new_xform.setPostCropArea(new_xform.transform().map(page_rect_phys));
+
 		return m_ptrNextTask->process(
-			status, data, content_rect_phys, page_rect_phys
+			status, FilterData(data, new_xform), content_rect_phys
 		);
-	} else {
+	} else if (m_ptrFilter->optionsWidget() != 0) {
 		return FilterResultPtr(
 			new UiUpdater(
 				m_ptrFilter, m_ptrSettings, m_pageId,
@@ -129,6 +135,8 @@ Task::process(
 				m_batchProcessing
 			)
 		);
+	} else {
+		return FilterResultPtr(0);
 	}
 }
 
