@@ -47,7 +47,11 @@ public:
 	
 	Dependencies(QSize const& image_size,
 		OrthogonalRotation rotation, LayoutType layout_type);
-	
+
+	void setLayoutType(LayoutType type) { m_layoutType = type; }
+
+	OrthogonalRotation const& orientation() const { return m_rotation; }
+
 	bool compatibleWith(Params const& params) const;
 	
 	bool isNull() const { return m_imageSize.isNull(); }
