@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,12 @@
 
 #include "ThumbnailBase.h"
 #include "PageLayout.h"
+#include "IntrusivePtr.h"
+#include <QPixmap>
 
+class QPointF;
 class QSizeF;
+class QPolygonF;
 class ThumbnailPixmapCache;
 class ImageId;
 class ImageTransformation;
@@ -33,16 +37,24 @@ namespace page_split
 class Thumbnail : public ThumbnailBase
 {
 public:
-	Thumbnail(ThumbnailPixmapCache& thumbnail_cache, QSizeF const& max_size,
-		ImageId const& image_id, ImageTransformation const& xform,
-		PageLayout const& layout);
+	Thumbnail(IntrusivePtr<ThumbnailPixmapCache> const& thumbnail_cache,
+		QSizeF const& max_size, ImageId const& image_id,
+		ImageTransformation const& xform, PageLayout const& layout,
+		bool left_half_removed, bool right_half_removed);
 	
 	virtual void paintOverImage(
 		QPainter& painter,
 		QTransform const& image_to_display,
 		QTransform const& thumb_to_display);
 private:
+	QPointF subPageCenter(
+		QPolygonF const& left_page, QPolygonF const& right_page,
+		QTransform const& image_to_display, int subpage_idx);
+
 	PageLayout m_layout;
+	QPixmap m_trashPixmap;
+	bool m_leftHalfRemoved;
+	bool m_rightHalfRemoved;
 };
 
 } // namespace page_split
