@@ -1,6 +1,6 @@
 /*
     Scan Tailor - Interactive post-processing tool for scanned pages.
-    Copyright (C) 2007-2009  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,6 +62,8 @@
 #include <stdlib.h>
 #include <limits.h>
 
+#include "CommandLine.h"
+
 namespace select_content
 {
 
@@ -120,12 +122,13 @@ ContentBoxFinder::findContentBox(
 	}
 	
 	uint8_t const darkest_gray_level = darkestGrayLevel(data.grayImage());
+	QColor const outside_color(darkest_gray_level, darkest_gray_level, darkest_gray_level);
 
 	QImage gray150(
 		transformToGray(
 			data.grayImage(), xform_150dpi.transform(),
 			xform_150dpi.resultingRect().toRect(),
-			QColor(darkest_gray_level, darkest_gray_level, darkest_gray_level)
+			OutsidePixels::assumeColor(outside_color)
 		)
 	);
 	// Note that we fill new areas that appear as a result of
@@ -141,7 +144,7 @@ ContentBoxFinder::findContentBox(
 	}
 	
 	PolygonRasterizer::fillExcept(
-		bw150, BLACK, xform_150dpi.resultingCropArea(), Qt::WindingFill
+		bw150, BLACK, xform_150dpi.resultingPreCropArea(), Qt::WindingFill
 	);
 	if (dbg) {
 		dbg->add(bw150, "page_mask_applied");
@@ -208,7 +211,13 @@ ContentBoxFinder::findContentBox(
 	
 	status.throwIfCancelled();
 	
-	BinaryImage despeckled(Despeckle::despeckle(content, Dpi(150, 150), Despeckle::NORMAL, status));
+	CommandLine const& cli = CommandLine::get();
+	Despeckle::Level despeckleLevel = Despeckle::NORMAL;
+	if (cli.hasContentRect()) {
+		despeckleLevel = cli.getContentDetection();
+	}
+
+	BinaryImage despeckled(Despeckle::despeckle(content, Dpi(150, 150), despeckleLevel, status, dbg));
 	if (dbg) {
 		dbg->add(despeckled, "despeckled");
 	}
@@ -1216,9 +1225,6 @@ ContentBoxFinder::trim(
 	}
 	
 	int const content_pixels = content.countBlackPixels(removed_area);
-	if (content_pixels < 20) {
-		return new_area;
-	}
 	
 	bool const vertical_cut = (
 		new_area.top() == area.top()
