@@ -96,6 +96,12 @@ Filter::pageOrderOptions() const
 	return m_pageOrderOptions;
 }
 
+void
+Filter::performRelinking(AbstractRelinker const& relinker)
+{
+	m_ptrSettings->performRelinking(relinker);
+}
+
 void
 Filter::preUpdateUI(FilterUiInterface* ui, PageId const& page_id)
 {
