@@ -18,6 +18,8 @@
 */
 
 #include <QCoreApplication>
+#include <QString>
+#include <QStringList>
 #include <iostream>
 
 #include "CommandLine.h"
@@ -28,6 +30,11 @@ int main(int argc, char **argv)
 {
 	QCoreApplication app(argc, argv);
 
+#ifdef _WIN32
+	// Get rid of all references to Qt's installation directory.
+	app.setLibraryPaths(QStringList(app.applicationDirPath()));
+#endif
+
 	// parse command line arguments
 	CommandLine cli(app.arguments(), false);
 	CommandLine::set(cli);
