@@ -54,3 +54,20 @@ ToLineProjector::projectionPoint(QPointF const& pt) const
 	return m_origin + m_vec * projectionScalar(pt);
 }
 
+QPointF
+ToLineProjector::projectionVector(QPointF const& pt) const
+{
+	return projectionPoint(pt) - pt;
+}
+
+double
+ToLineProjector::projectionDist(QPointF const& pt) const
+{
+	return sqrt(projectionSqDist(pt));
+}
+
+double
+ToLineProjector::projectionSqDist(QPointF const& pt) const
+{
+	return Vec2d(projectionPoint(pt) - pt).squaredNorm();
+}
