@@ -25,6 +25,7 @@
 #include "adiff/Function.h"
 #include <QLineF>
 #include <QDebug>
+#include <boost/foreach.hpp>
 #include <string>
 #include <stdexcept>
 #include <algorithm>
@@ -656,7 +657,7 @@ XSpline::junctionPointsAttractionForce(int seg_begin, int seg_end) const
 			Function<2> next_y(sparse_map);
 			
 			linearCombinationAt(controlPointIndexToT(i), coeffs);
-            for (LinearCoefficient const& coeff: coeffs) {
+			BOOST_FOREACH(LinearCoefficient const& coeff, coeffs) {
 				QPointF const cp(m_controlPoints[coeff.controlPointIdx].pos);
 				Function<2> x(coeff.controlPointIdx * 2, cp.x(), sparse_map);
 				Function<2> y(coeff.controlPointIdx * 2 + 1, cp.y(), sparse_map);
