@@ -1,7 +1,7 @@
 /*
 
 	Scan Tailor - Interactive post-processing tool for scanned pages.
-	Copyright (C) 2007-2009  Joseph Artsimovich <joseph_a@mail.ru>
+	Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>
 
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 #include "PropertySet.h"
 #include "IntrusivePtr.h"
 #include <QObject>
+#include <boost/mpl/bool.hpp>
+#include <boost/foreach.hpp>
 #include <boost/iterator/iterator_facade.hpp>
 #include <map>
 
@@ -102,4 +104,18 @@ private:
 	PropertySet m_defaultProps;
 };
 
+namespace boost
+{
+namespace foreach
+{
+
+// Make BOOST_FOREACH work with the above class (necessary for boost >= 1.46 with gcc >= 4.6)
+template<>
+struct is_noncopyable<EditableZoneSet> : public boost::mpl::true_
+{
+};
+
+} // namespace foreach
+} // namespace boost
+
 #endif
